@@ -1,14 +1,14 @@
-# Copyrights 1995-2019 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 1995-2024 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of the bundle MailTools.  Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md for Copyright.
 # Licensed under the same terms as Perl itself.
 
-package Mail::Field::Date;
-use vars '$VERSION';
-$VERSION = '2.21';
+package Mail::Field::Date;{
+our $VERSION = '2.22';
+}
 
 use base 'Mail::Field';
 
